@@ -1,6 +1,6 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	@(#) mhamain.pl 2.25 01/08/26 12:52:32
+##	@(#) mhamain.pl 2.30 01/11/13 23:09:14
 ##  Author:
 ##      Earl Hood       mhonarc@mhonarc.org
 ##  Description:
@@ -27,9 +27,9 @@
 
 package mhonarc;
 
-$VERSION = "2.5.0b";
+$VERSION = "2.5.1";
 $VINFO =<<EndOfInfo;
-  MHonArc v$VERSION (Perl $])
+  MHonArc v$VERSION (Perl $] $^O)
   Copyright (C) 1995-2001  Earl Hood, mhonarc\@mhonarc.org
   MHonArc comes with ABSOLUTELY NO WARRANTY and MHonArc may be copied only
   under the terms of the GNU General Public License, which may be found in
@@ -275,7 +275,7 @@ sub doit {
 	## Read mail head
 	($index, $fields) = read_mail_header($handle);
 
-	if ($index ne '') {
+	if ($index) {
 	    $AddIndex{$index} = 1;
 	    $IndexNum{$index} = &getNewMsgNum();
 
@@ -316,7 +316,7 @@ sub doit {
 		    ($index, $fields) = read_mail_header($fh);
 
 		    #  Process message if valid
-		    if ($index ne '') {
+		    if ($index) {
 			if ($ADD && !$SLOW) { $AddIndex{$index} = 1; }
 			$IndexNum{$index} = &getNewMsgNum();
 			$Message{$index} = &read_mail_body(
@@ -353,7 +353,7 @@ sub doit {
 		    print STDOUT "."  unless $QUIET;
 		    ($index, $fields) = read_mail_header($fh);
 
-		    if ($index ne '') {
+		    if ($index) {
 			if ($ADD && !$SLOW) { $AddIndex{$index} = 1; }
 			$IndexNum{$index} = &getNewMsgNum();
 			$Message{$index} = read_mail_body(
@@ -391,6 +391,7 @@ sub doit {
 	print STDOUT "No new messages\n"  unless $QUIET;
 	return 1;
     }
+    $NewMsgCnt = $NumOfMsgs - $i;
 
     ## Write pages
     &write_pages();
@@ -613,7 +614,10 @@ sub write_pages {
 	}
     }
 
-    print STDOUT "$NumOfMsgs messages\n"  unless $QUIET;
+    unless ($QUIET) {
+	print STDOUT "$NewMsgCnt new messages\n"  if $NewMsgCnt > 0;
+	print STDOUT "$NumOfMsgs total messages\n";
+    }
 
 } ## End: write_pages()
 
@@ -686,7 +690,7 @@ sub write_mail {
 ##
 sub read_mail_header {
     my $handle = shift;
-    my($header, $index, $date, $tmp);
+    my($index, $date, $tmp);
     my($from, $sub, $msgid, $ctype);
     local($_);
 
@@ -698,8 +702,10 @@ sub read_mail_header {
     ## Check for no archive flag ##
     ##---------------------------##
     if ( $CheckNoArchive &&
-	 ($fields->{'restrict'}[0] =~ /no-external-archive/i ||
-	  $fields->{'x-no-archive'}[0] =~ /yes/i) ) {
+	 (defined($fields->{'restrict'}) &&
+	  grep { /no-external-archive/i } @{$fields->{'restrict'}}) ||
+	 (defined($fields->{'x-no-archive'}) &&
+	  grep { /yes/i } @{$fields->{'x-no-archive'}}) ) {
 	return undef;
     }
 
@@ -746,7 +752,7 @@ sub read_mail_header {
     ##----------##
     ## Get date ##
     ##----------##
-    $date = "";  $index = "";
+    $date = "";
     foreach (@DateFields) {
 	next  unless defined($fields->{$_});
 
@@ -766,7 +772,7 @@ sub read_mail_header {
 	    last;
 	}
     }
-    if ($index eq "") {
+    if (!$index) {
 	warn qq/\nWarning: Could not parse date for message\n/,
 	       qq/         Message-Id: <$msgid>\n/;
 	# Use current time
@@ -825,7 +831,7 @@ sub read_mail_header {
     ## Get Content-Type ##
     ##------------------##
     if (defined($fields->{'content-type'})) {
-	($ctype = $fields->{'content-type'}[0]) =~ m%^\s*([\w-\./]+)%;
+	($ctype = $fields->{'content-type'}[0]) =~ m%^\s*([\w\-\./]+)%;
 	$ctype = lc ($1 || 'text/plain');
     } else {
 	$ctype = 'text/plain';
