@@ -1,13 +1,13 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	@(#) mhidxrc.pl 2.7 00/10/28 10:47:42
+##	@(#) mhidxrc.pl 2.10 01/09/17 22:09:15
 ##  Author:
-##      Earl Hood       mhonarc@pobox.com
+##      Earl Hood       mhonarc@mhonarc.org
 ##  Description:
 ##      MHonArc library defining values for various index resources
 ##---------------------------------------------------------------------------##
 ##    MHonArc -- Internet mail-to-HTML converter
-##    Copyright (C) 1996-1999	Earl Hood, mhonarc@pobox.com
+##    Copyright (C) 1996-1999	Earl Hood, mhonarc@mhonarc.org
 ##
 ##    This program is free software; you can redistribute it and/or modify
 ##    it under the terms of the GNU General Public License as published by
@@ -269,6 +269,11 @@ unless ($TSLICEEND) {
     $IsDefault{'TSLICEEND'} = 1;
 }
 
+if ($TSLICELEVELS < 0) {
+    $TSLICELEVELS = $TLEVELS;
+    $IsDefault{'TSLICELEVELS'} = 1;
+}
+
 unless ($TSLICESINGLETXT) {
     $TSLICESINGLETXT = $TSINGLETXT;
     $IsDefault{'TSLICESINGLETXT'} = 1;
