@@ -1,13 +1,13 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##      @(#) mhopt.pl 2.21 01/08/26 02:25:24
+##      @(#) mhopt.pl 2.24 01/11/13 23:09:36
 ##  Author:
-##      Earl Hood       mhonarc@pobox.com
+##      Earl Hood       mhonarc@mhonarc.org
 ##  Description:
 ##      Routines to set options for MHonArc.
 ##---------------------------------------------------------------------------##
 ##    MHonArc -- Internet mail-to-HTML converter
-##    Copyright (C) 1997-1999	Earl Hood, mhonarc@pobox.com
+##    Copyright (C) 1997-1999	Earl Hood, mhonarc@mhonarc.org
 ##
 ##    This program is free software; you can redistribute it and/or modify
 ##    it under the terms of the GNU General Public License as published by
@@ -178,6 +178,8 @@ sub get_resources {
 	"tlevels=i",	# Maximum # of nested lists in threaded index
 	"treverse",	# Reverse order of thread listing
 	"tslice=s",	# Set size of thread slice listing
+	"tslicelevels=i",
+			# Maximum # of nested lists in thread slices
 	"tsort",	# List threads by date
 	"tsubsort",	# List threads by subject
 	"umask=i",	# Set umask of process
@@ -280,7 +282,7 @@ sub get_resources {
     require 'mhrmm.pl'  	if $RMM;
     require 'mhnote.pl'  	if $ANNOTATE;
 
-    print STDOUT "This is MHonArc v$VERSION, Perl $]\n";
+    print STDOUT "This is MHonArc v$VERSION, Perl $] $^O\n"  unless $QUIET;
 
     ## Evaluate site local initialization
     delete($INC{'mhasiteinit.pl'});      # force re-evaluation
@@ -431,8 +433,8 @@ sub get_resources {
 	unshift(@PerlINC, @array);
     }
 
-    @OtherIdx = remove_dups(\@OtherIdxs);
-    @PerlINC  = remove_dups(\@PerlINC);
+    @OtherIdxs = remove_dups(\@OtherIdxs);
+    @PerlINC   = remove_dups(\@PerlINC);
 
     ## Require mail parsing library
     unshift(@INC, @PerlINC);
@@ -465,6 +467,7 @@ sub get_resources {
     $GzipExe	= $opt{'gzipexe'}    if $opt{'gzipexe'};
     $VarExp	= $opt{'varregex'}   if $opt{'varregex'} &&
 				        ($opt{'varregex'} =~ /\S/);
+    $TSLICELEVELS = $opt{'tslicelevels'}  if $opt{'tslicelevels'};
 
     $IDXNAME	= $opt{'idxfname'} || $IDXNAME || $ENV{'M2H_IDXFNAME'} ||
 		  "maillist.$HtmlExt";
