@@ -1,6 +1,6 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	@(#) mhtxthtml.pl 2.17 01/08/26 02:10:34
+##	@(#) mhtxthtml.pl 2.19 01/10/07 23:04:43
 ##  Author:
 ##      Earl Hood       mhonarc@mhonarc.org
 ##  Description:
@@ -36,18 +36,18 @@ package m2h_text_html;
 my $Url	= '(\w+://|\w+:)';
 
 # Script related attributes
-my $SAttr = q/(?:onload|onunload|onclick|ondblclick|/.
+my $SAttr = q/\b(?:onload|onunload|onclick|ondblclick|/.
 	    q/onmouse(?:down|up|over|move|out)|/.
-	    q/onkey(?:press|down|up))/;
+	    q/onkey(?:press|down|up))\b/;
 # Script/questionable related elements
-my $SElem = q/(?:applet|base|embed|form|ilayer|input|layer|link|meta|object|/.
-	    q/option|param|select|textarea)/;
+my $SElem = q/\b(?:applet|base|embed|form|ilayer|input|layer|link|meta|object|/.
+	    q/option|param|select|textarea)\b/;
 
 # Elements with auto-loaded URL attributes
-my $AElem = q/(?:img|body|iframe|frame|object|script|input)/;
+my $AElem = q/\b(?:img|body|iframe|frame|object|script|input)\b/;
 	    # XXX: What about INS, DEL?
 # URL attributes
-my $UAttr = q/(?:href|src|background|classid|data|longdesc)/;
+my $UAttr = q/\b(?:href|src|background|classid|data|longdesc)\b/;
 	    # XXX: What about codebase, usemap?
 
 ##---------------------------------------------------------------------------
@@ -80,13 +80,33 @@ my $UAttr = q/(?:href|src|background|classid|data|longdesc)/;
 ##			to scripting.  The default is to delete any
 ##			scripting markup for security reasons.
 ##
+##	attachcheck	Honor attachment disposition.  By default,
+##			all text/html data is displayed inline on
+##			the message page.  If attachcheck is specified
+##			and Content-Disposition specifies the data as
+##			an attachment, the data is saved to a file
+##			with a link to it from the message page.
+##
 ##	nofont  	Remove <FONT> tags.
 ##
 ##	notitle  	Do not print title.
 ##
 sub filter {
     my($fields, $data, $isdecode, $args) = @_;
-    local(@files) = ();	# !!!Used by resolve_cid!!!
+    $args = ''  unless defined $args;
+
+    ## Check if content-disposition should be checked
+    if ($args =~ /\battachcheck\b/i) {
+	my($disp, $nameparm) = readmail::MAILhead_get_disposition($fields);
+	if ($disp =~ /\battachment\b/i) {
+	    require 'mhexternal.pl';
+	    return (m2h_external::filter(
+		      $fields, $data, $isdecode,
+		      readmail::get_filter_args('m2h_external::filter')));
+	}
+    }
+
+    local(@files) = ();	# XXX: Used by resolve_cid!!!
     my $base 	 = '';
     my $title	 = '';
     my $noscript = 1;
@@ -146,14 +166,14 @@ sub filter {
     if ($noscript) {
 	$$data =~ s|<script[^>]*>.*?</script\s*>||gios;
 	$$data =~ s|<style[^>]*>.*?</style\s*>||gios  unless $nofont;
-	$$data =~ s|\b$SAttr\b\s*=\s*"[^"]*"||gio; #"
-	$$data =~ s|\b$SAttr\b\s*=\s*'[^']*'||gio; #'
-	$$data =~ s|\b$SAttr\b\s*=\s*[^\s>]+||gio;
+	$$data =~ s|$SAttr\s*=\s*"[^"]*"||gio; #"
+	$$data =~ s|$SAttr\s*=\s*'[^']*'||gio; #'
+	$$data =~ s|$SAttr\s*=\s*[^\s>]+||gio;
 	$$data =~ s|</?$SElem[^>]*>||gio;
     }
     
     if ($onlycid) {
-        $$data =~ s/($AElem\b[^>]+$UAttr\s*=\s*['"])([^'"]+)(['"])
+        $$data =~ s/($AElem[^>]+$UAttr\s*=\s*['"])([^'"]+)(['"])
 		   /&preserve_cid($1, $2, $3)
 		   /geoix;
     }
@@ -178,7 +198,7 @@ sub filter {
 	    $tpre .= qq|background-color: $attr{'bgcolor'}; |
 		     if $attr{'bgcolor'};
 	    if ($attr{'background'}) {
-		if ($attr{'background'} =~ s/^cid://i) {
+		if ($attr{'background'} =~ /^cid:/i) {
 		    $attr{'background'} = &resolve_cid($attr{'background'});
 		} else {
 		    $attr{'background'} = &addbase($base, $attr{'background'});
