@@ -1,13 +1,13 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	@(#) mhutil.pl 2.10 01/08/26 02:17:15
+##	@(#) mhutil.pl 2.13 01/10/06 20:02:15
 ##  Author:
-##      Earl Hood       mhonarc@pobox.com
+##      Earl Hood       mhonarc@mhonarc.org
 ##  Description:
 ##      Utility routines for MHonArc
 ##---------------------------------------------------------------------------##
 ##    MHonArc -- Internet mail-to-HTML converter
-##    Copyright (C) 1995-1999	Earl Hood, mhonarc@pobox.com
+##    Copyright (C) 1995-1999	Earl Hood, mhonarc@mhonarc.org
 ##
 ##    This program is free software; you can redistribute it and/or modify
 ##    it under the terms of the GNU General Public License as published by
@@ -59,7 +59,8 @@ my %HFieldsAddr = (
 ##	Get an e-mail address from (HTML) $str.
 ##
 sub extract_email_address {
-    my($str) = shift;
+    return ''  unless defined $_[0];
+    my $str = shift;
     my($ret);
 
     if ($str =~ /<(\S+)>/) {
@@ -255,8 +256,8 @@ sub get_base_author {
 ##	Determine time from date.  Use %Zone for timezone offsets
 ##
 sub get_time_from_date {
-    local($mday, $mon, $yr, $hr, $min, $sec, $zone) = @_;
-    local($time) = 0;
+    my($mday, $mon, $yr, $hr, $min, $sec, $zone) = @_;
+    my($time) = 0;
 
     $yr -= 1900  if $yr >= 1900;  # if given full 4 digit year
     $yr += 100   if $yr <= 37;    # in case of 2 digit years
@@ -458,7 +459,10 @@ sub newsurl {
 ##	$html = mailUrl($email_addr, $msgid, $subject, $from);
 ##
 sub mailUrl {
-    my($eaddr, $msgid, $sub, $from) = @_;
+    my $eaddr = shift || '';
+    my $msgid = shift || '';
+    my $sub = shift || '';
+    my $from = shift || '';
 
     local $_;
     my($url) = ($MAILTOURL);
@@ -471,8 +475,8 @@ sub mailUrl {
     my($subjectl);
 
     # Add "Re:" to subject if not present
-    if ($sub !~ /^\s*Re:/) {
-	$subjectl = &urlize("Re: ") . &urlize($sub);
+    if ($sub !~ /^$SubReplyRxp/io) {
+	$subjectl = 'Re:%20' . &urlize($sub);
     } else {
 	$subjectl = &urlize($sub);
     }
@@ -562,6 +566,30 @@ sub is_follow_ups_diff {
     return (defined($f) || defined($o));
 }
 
+##---------------------------------------------------------------------------##
+##	Retrieve icon URL for specified content-type.
+##
+sub get_icon_url {
+    my $ctype = shift;
+    my $icon = $Icons{$ctype};
+    ICON: {
+	last ICON  if defined $icon;
+	if ($ctype =~ s|/.*||) {
+	  $ctype .= '/*';
+	  $icon = $Icons{$ctype};
+	  last ICON  if defined $icon;
+	}
+	$icon = $Icons{'*/*'} || $Icons{'unknown'};
+    }
+    if (!defined($icon)) {
+	return (undef, undef, undef);
+    }
+    if ($icon =~ s/\[(\d+)x(\d+)\]//) {
+	return ($icon, $1, $2);
+    }
+    ($icon, undef, undef);
+}
+
 ##---------------------------------------------------------------------------##
 
 sub log_mesg {
